This directory contains example notebooks explaining core RAIL functionality.

- [FileIO_DataStore.ipynb](https://lsstdescrail.readthedocs.io/en/latest/source/core-notebooks.html#data-files-io-and-rail) demonstrates a variety of ways that users may interact with data in RAIL.

- [hyperbolic_magnitude_test.ipynb](https://lsstdescrail.readthedocs.io/en/latest/source/core-notebooks.html#computing-hyperbolic-magnitudes) provides an example of how to convert classical to hyperbolical magnitudes using the pipeline stages HyperbolicSmoothing and HyperbolicMagnitudes in the rail.core module

- [iterator_test.ipynb](https://lsstdescrail.readthedocs.io/en/latest/source/core-notebooks.html#iterator-test) explains how to iterate over hdf5 data files interactively.

- [Pipe_Example.ipynb](https://lsstdescrail.readthedocs.io/en/latest/source/core-notebooks.html#pipeline-example) explains how to build a RAIL pipeline interactively.

- [Run_Pipe.ipynb](https://lsstdescrail.readthedocs.io/en/latest/source/core-notebooks.html#run-pipe) explains how to run a pre-built RAIL pipeline interactively.
